#!/opt/VRTSsfmh/bin/perl
#
#$Id$
#$Source$
# $Copyright (c) 2018 Veritas Technologies LLC.  All rights reserved. Veritas
# and the Veritas Logo are trademarks or registered trademarks of Veritas
# Technologies LLC or its affiliates in the U.S. and other countries. Other
# names may be trademarks of their respective owners.
#
# The Licensed Software and Documentation are deemed to be commercial computer
# software as defined in FAR 12.212 and subject to restricted rights as defined
# in FAR Section 52.227-19 "Commercial Computer Software - Restricted Rights" and
# DFARS 227.7202, et seq. "Commercial Computer Software and Commercial Computer
# Software Documentation," as applicable, and any successor regulations, whether
# delivered by Veritas as on premises or hosted services. Any use, modification,
# reproduction release, performance, display or disclosure of the Licensed Software
# and Documentation by the U.S. Government shall be solely in accordance with the
# terms of this Agreement. $
#
BEGIN { @INC = ("/opt/VRTSsfmh/lib/modules") if ( $^O !~ /Win32/i ) }

use strict;
use warnings;
use VRTS::Paths;
use File::Path qw(mkpath rmtree);
use File::Spec qw(catdir curdir);
use VRTS::OS;
use VRTS::Ini;
use VRTS::Util;
use Cwd;

my $install_dir = VRTS::Paths::get_path("InstallDir");
$install_dir = File::Spec->canonpath($install_dir);
if (!defined($install_dir)) {
    print("Cannot get Veritas InfoScale Operations Manager install directory\n");
}

my $mhbin = File::Spec->catdir($install_dir, "bin");
my $mhbin_perl = File::Spec->catfile($mhbin, "perl");

# Removing addon Constants..
my $real_const_dir = File::Spec->catdir($install_dir, "agentlet", "VRTS", "Constants");
my $cmd  = File::Spec->catfile($install_dir, "bin", "tdf2constant.pl");
my $tdfdir = File::Spec->catdir($install_dir, "etc", "tdf", "BRCD");
my $cmd1 = make_command($mhbin_perl, $cmd, "--dir", $tdfdir);

# Generate constants which will get generated under 'Constants' dir under CWD
my $out = system ($cmd1);
my $c_dir = getcwd();

my $temp_const_dir = File::Spec->catdir($c_dir, "Constants");

opendir(DIR, "$temp_const_dir");

# Look for same file name in original directory and delete the same
while(defined(my $file = readdir(DIR))) {
    # NOTE: Don't delete constants for tdfs that are shared with other
    # components.
    if (($file eq "P_ARRAY_CONFIG.pm") ||
                    ($file eq "P_ARRAY_CONFIG_ARRAY_MAPPING.pm") ||
                    ($file eq "FAULT_OBJ.pm") ||
                    ($file eq "HOST_TO_FAULT.pm")) {
        # constants shared with SI addon or other components. Don't delete.
        next;
    }
        
    my $real_file = File::Spec->catfile($real_const_dir, $file);
    if (-f $real_file)
    {
        unlink($real_file);
    }
}
close(DIR);

# Removing the temporary constants directory
File::Path::rmtree($temp_const_dir);

# Delete files installed by the addon
for my $remf (
    "agentlet/VRTS/BRCD",
    "agentlet/VRTS/CISCO",
    "etc/tdf/BRCD",
    "etc/tdf/CISCO",
    "operations/probe_switch",
    "operations/refresh_switch_config",
    "operations/switch_discovery_sched",
    "operations/jobs/probe_switch.pm",
    "operations/jobs/refresh_switch_config.pm",
    "operations/jobs/switch_discovery_sched.pm",
    "bin/switch_driver.pl",
    "lib/modules/VRTS/Fabric"
# Not deleting perl modules that we put in in case they are shared in future
) {
    rmtree("$install_dir/$remf");
}

# Unregister fabric families
# Get domains to which this host is configured
my $sfm_conf = VRTS::OS->get_resolv();
my @doms;
my $result = VRTS::Ini->query_section($sfm_conf, "domains", \@doms);
if ($result != 0) {
    print STDERR "Failed to get domains from [$sfm_conf]\n";
    exit(1);
}
my $mhctl = File::Spec->catfile($mhbin,"mh_ctl.pl");
foreach my $fam ("BRCD", "CISCO") {
    foreach my $dom (@doms) {
        my $cmd = make_command($mhbin_perl, $mhctl, "--family", $fam,
                "--unregister", "--domain", $dom);
        system($cmd);
    }
}

# If the current host is MS, remove the FI addon OLH
my $csinstalldir = $install_dir;
# Replace ending VRTSsfmh by VRTSsfmcs and also remove ending '/' or '\' if any
$csinstalldir =~ s/VRTSsfmh[\/\\]?$/VRTSsfmcs/;
if (-d "$csinstalldir") {
    my $fiolhdir = File::Spec->catdir($csinstalldir, "webgui",
            "vom", "help", "content", "EN_US", "VIOMFIADDONCURRENT7_4");
    if (-d "$fiolhdir") {
        rmtree("$fiolhdir");
    }
}

print "Fabric Add-on uninstalled successfully";
exit(0);
